#' 様々な種類のわかりやすい行列の作成
#'
#' 様々な種類のわかりやすい行列の作成する。 \cr
#' 英語のヘルプ： \link[TestJP]{demomat}
#'
#' @param nr 行の数、または行の数からなるベクトル
#' @param nc # of columns of the matrix to be generated
#'    or a vector consisting of the # of columns of each submatrix.
#' @param n3 # of the 3d dimension or 0, if any
#' @param root The root character of the elements of the symbolic matrix. \cr
#' If this is present, a character matrix/array will be created.
#' @param vec = 1 to drop the redundant subscript.
#' @param shape Shape of the resulting matrix: \cr
#'        "sym", "symU", "symL", "diag", "uppert", "lowert"
#' @param nodiag = 1 to set the diagonal elements to 0 when either
#'             "upper" or "lower" is specified
#' @param list = 1 to return the array as list when n3 > 2.
#' @param fullsymb = 1 to make the result a fully symbolic matrix
#' @param mul   See below.
#' @param mul3  See below.
#' @param rnroot root of the row names
#' @param cnroot root of the column names
#' @param anroot root of the third dimension names
#' @param supermat = 1 to create horizontally stacked array\cr
#' = 2 to create vertically stacked array\cr
#' = 0 othereize
#'
#' @details 行列の i,j 要素には mul*i + j という添字が付与される。\cr
#'  The i,j,k elements of an array will be named as mul3*(mul*i + j) + k\cr
#'  \cr
#'  When a supermatrix is generated, SMdim attributes will be set \cr
#'  where SMdim	is a list of the form \cr
#'  (nrows=nr, ncols=nc, rownames=rn, colnames=cn, anames=an) \cr
#'  where \cr
#'   nr is a vector consisting of the number of rows of each submatrix, \cr
#'   nc is a vector consisting of the number of columns of each submatrix \cr
#'   rn is a vector consisting of the supplemental row names \cr
#'   cn is a vector consisting of the supplemental column names \cr
#'   an is a vector consisting of the names associated with the 3rd dim.\cr
#'   '
#' @return 行列もしくは 3D 配列 \cr
#' vec=1 が指定されていても、列数もしくは行数が 1 の行列が出力されるため
#' ベクトルがほしい場合には c() を作用させること。
#'
#' @examples
#' demomat( 11,3 ) # 数値
#' demomat( 11,3,root="a" ) # 記号
#' demomat( 4,1,root="a", vec=1 ) # symbolic matrix
#'
#' demomat( 4,3,2 ) # numeric array
#' demomat( 4,3,2, supermat=1 ) # numeric supermatrix (horizontally stacked)
#' demomat( 4,3,2, supermat=2 ) # numeric supermatrix (vertically stacked)
#'
#' # Below two creates almost identical super matrices.
#' demomat( 4,3,2, root="a", supermat=1 )
#' demomat( 4,c(3,3), root="a" )
#'
#' # 2 x 2 partitioned matrix
#' A=demomat( c(4,3),c(3,2), root="a" )
#' 
#'
#'
#' @docType package
#' @name demomat_JPH
NULL

