#' 複数のオブジェクトを名前を付けて表示する。
#'
#' 英語のヘルプ： \link[TestJP]{printm}.
#'
#' @param ... 表示したいオブジェクト（行列、データフレーム等）
#' @param .sep. delimiter string
#' @param .NAchar. a character to indicate NA
#' @param .FILL. string of length 2 to be used to fill in the blanks
#'
#' @details Printing  array may be misleading. \cr
#'
#' This function can print data.frames with other objects.
#' In contrast, \code{lazy.tools::Print} cannot print data.frames
#' but allows some formatting.
#'
#' Those characters which match the value of .FILL. will be printed as blanks.
#' If you know that the objects contain ".^", change the definition of .FILL..
#'
#' When the actual arguments consist of string literals or numbers,
#' they will be printed without names.
#'
#' If the objects contain UTF-8 characters, the result may be misleading
#' due to the bug of \code{print.data.frame} method.
#'
#' @examples
#' Mat <- matrix(1:6,3,2, dimnames=list(NULL,c("c1","C2")))
#' DF <- as.data.frame(Mat)
#' DF[2,2] <- NA
#' printm( 1.5:2.5, letters[1:2], Mat, DF, c(TRUE,FALSE), .sep.=",    " )
#' printm( "This is an example.", DF, 123, Mat+Mat )
#'
#' d1 <- data.frame(x=1:3,y=11:13)
#' d2 <- data.frame(x=21:24,y=31:34)
#' ld <- list(d1,d2)
#' df <- as.data.frame(rbind(d1,d2))
#' printm(d1,d2,ld,df,NULL,d1)
#'
#'
#'
#' @docType package
#' @name printm_JPH
NULL
